import os
import pathlib

import pooch

if __name__ == '__main__':
    here = pathlib.Path(os.path.dirname(__file__))
    data_dir = here / 'data'

    pooch.make_registry(data_dir, here / 'pythia_datasets/registry.txt')



#!/usr/bin/env python3
# flake8: noqa
"""Top-level module for pythia-datasets ."""
from pkg_resources import DistributionNotFound, get_distribution

from .datasets import DATASETS, locate

try:
    __version__ = get_distribution(__name__).version
except DistributionNotFound:  # pragma: no cover
    # package is not installed
    __version__ = 'unknown'  # pragma: no cover
